module.exports = {
  env: {
    browser: true,
    es6: true,
    jest: true,
    node: true,
  },
  extends: [ 'eslint:recommended' ],
  overrides: [
    {
      files: [ '*.styles.{js,ts}' ],
      rules: {
        'sort-keys': 'off',
      },
    },
  ],
  parser: 'babel-eslint',
  parserOptions: {
    ecmaFeatures: {
      classes: true,
      impliedStrict: true,
    },
    ecmaVersion: '2019',
  },
  plugins: [],
  rules: {
    'array-bracket-newline': [
      'error',
      {
        minItems: 3,
        multiline: true,
      },
    ],
    'array-bracket-spacing': [
      'error',
      'never',
      {
        singleValue: true,
      },
    ],
    'array-callback-return': [ 'error' ],
    'array-element-newline': [
      'error',
      {
        minItems: 3,
        multiline: true,
      },
    ],
    'arrow-body-style': [ 'error' ],
    'arrow-parens': [ 'error' ],
    'arrow-spacing': [ 'error' ],
    'block-spacing': [ 'error' ],
    'brace-style': [ 'error' ],
    camelcase: 'off',
    'comma-dangle': ['error', 'always-multiline'],
    'comma-spacing': [ 'error' ],
    'comma-style': [ 'error' ],
    'computed-property-spacing': [ 'error' ],
    'consistent-return': [ 'error' ],
    curly: [ 'error' ],
    'default-case': [ 'error' ],
    'dot-notation': [
      'error',
      {
        allowPattern: '^[a-z]+(_[a-z]+)+$',
      },
    ],
    'eol-last': [ 'error' ],
    eqeqeq: [ 'error' ],
    'func-call-spacing': [ 'error' ],
    'func-name-matching': [ 'error' ],
    'func-names': ['error', 'as-needed'],
    'generator-star-spacing': [ 'error' ],
    'implicit-arrow-linebreak': [ 'error' ],
    indent: 'off',
    'jsx-quotes': [ 'error' ],
    'key-spacing': [ 'error' ],
    'keyword-spacing': [ 'error' ],
    'line-comment-position': [ 'error' ],
    'lines-between-class-members': [ 'error' ],
    'max-depth': [ 'error' ],
    'max-len': [
      'error',
      {
        code: 150,
        ignoreComments: true,
        ignoreStrings: true,
        tabWidth: 2,
      },
    ],
    'max-params': [ 'error' ],
    'max-statements-per-line': [
      'error',
      {
        max: 1,
      },
    ],
    'multiline-ternary': ['error', 'always-multiline'],
    'new-parens': [ 'error' ],
    'newline-after-var': ['error', 'always'],
    'newline-per-chained-call': [ 'error' ],
    'no-alert': [ 'error' ],
    'no-bitwise': [ 'error' ],
    'no-continue': [ 'error' ],
    'no-duplicate-imports': [ 'error' ],
    'no-else-return': [ 'error' ],
    'no-empty-function': [ 'error' ],
    'no-eq-null': [ 'error' ],
    'no-eval': [ 'error' ],
    'no-extra-bind': [ 'error' ],
    'no-floating-decimal': [ 'error' ],
    'no-implicit-globals': [ 'error' ],
    'no-implied-eval': [ 'error' ],
    'no-inline-comments': [ 'error' ],
    'no-iterator': [ 'error' ],
    'no-lone-blocks': [ 'off' ],
    'no-lonely-if': [ 'error' ],
    'no-loop-func': [ 'error' ],
    'no-mixed-operators': [ 'error' ],
    'no-multi-assign': [ 'error' ],
    'no-multi-spaces': [ 'error' ],
    'no-multiple-empty-lines': [
      'error',
      {
        max: 1,
      },
    ],
    'no-nested-ternary': [ 'error' ],
    'no-new': [ 'error' ],
    'no-new-func': [ 'error' ],
    'no-new-object': [ 'error' ],
    'no-new-wrappers': [ 'error' ],
    'no-param-reassign': [ 'error' ],
    'no-plusplus': [ 'error' ],
    'no-proto': [ 'error' ],
    'no-return-assign': [ 'error' ],
    'no-return-await': [ 'error' ],
    'no-script-url': [ 'error' ],
    'no-self-compare': [ 'error' ],
    'no-sequences': [ 'error' ],
    'no-template-curly-in-string': [ 'error' ],
    'no-trailing-spaces': [ 'error' ],
    'no-undef-init': [ 'error' ],
    'no-unmodified-loop-condition': [ 'error' ],
    'no-unneeded-ternary': [ 'error' ],
    'no-use-before-define': [ 'error' ],
    'no-useless-catch': [ 'error' ],
    'no-useless-computed-key': [ 'error' ],
    'no-useless-concat': [ 'error' ],
    'no-useless-escape': [ 'error' ],
    'no-useless-return': [ 'error' ],
    'no-var': [ 'error' ],
    'no-whitespace-before-property': [ 'error' ],
    'operator-assignment': [ 'error' ],
    'prefer-const': [ 'error' ],
    'prefer-destructuring': [ 'error' ],
    'prefer-object-spread': [ 'error' ],
    'prefer-rest-params': [ 'error' ],
    'prefer-spread': [ 'error' ],
    'quote-props': ['error', 'as-needed'],
    quotes: ['error', 'single'],
    radix: [ 'error' ],
    'rest-spread-spacing': [ 'error' ],
    semi: [ 'error' ],
    'semi-spacing': [ 'error' ],
    'sort-imports': [
      'error',
      {
        ignoreCase: true,
        memberSyntaxSortOrder: [
          'multiple',
          'single',
          'all',
          'none',
        ],
      },
    ],
    'sort-keys': [
      'error',
      'asc',
      {
        caseSensitive: false,
      },
    ],
    'space-before-blocks': ['error', 'always'],
    'space-before-function-paren': [
      'error',
      {
        anonymous: 'always',
        asyncArrow: 'always',
        named: 'never',
      },
    ],
    'space-in-parens': [ 'error' ],
    'space-infix-ops': [ 'error' ],
    'spaced-comment': [ 'error' ],
    'template-curly-spacing': [ 'error' ],
  },
};
